args <- commandArgs(TRUE)
msfFile <- args[[1]]
outputTablePath <- args[[2]]

cat("Loading R libraries...\n")
require(RSQLite)
#require(sqldf)
driver = dbDriver("SQLite")
con <- dbConnect(driver, dbname = msfFile)
#confidence <- switch(minConf, High = 3, Medium = 2, Low = 1, 3)
confidence <- 1  # default to capture all identifications

sql_mtz <- paste("SELECT p.PeptideID,\n",
                         # --- attributes from Java source code --- #
                         "p.ProcessingNodeNumber,\n",
                         "p.Sequence,\n",
                         "p.SpectrumID,\n",
                         "p.TotalIonsCount,\n",
                         "p.MatchedIonsCount,\n",
                         "p.ConfidenceLevel,\n",
                         "p.SearchEngineRank,\n",
                         "p.Annotation,\n",
                         "p.UniquePeptideSequenceID,\n",
                         "p.MissedCleavages,\n",
                         ####
                         "sh.ScanNumbers,\n",
                         "sh.RetentionTime,\n",
                         "sh.Mass,\n",
                         "sh.Charge,\n",
                         ####
                         #"sh.MassPeakID\n",
                         "mp.Intensity,\n",
                         "mp.PercentIsolationInterference,\n",
                         "mp.IonInjectTime,\n",
                         "mp.Mass AS MZ,\n",
                         ####
                         "se.MSLevel,\n",
                         "se.ActivationType,\n",
                         "fi.FileName\n",
                         ####
                         # ----------------except #"ss.Score,\n",------------------------ #
                 "FROM Peptides AS p, SpectrumHeaders AS sh, MassPeaks AS mp,\n",
                      "ScanEvents AS se, FileInfos AS fi\n",#, SpectrumScores AS ss\n",
                 "WHERE p.SpectrumID=sh.SpectrumID AND", "p.ConfidenceLevel >=", confidence,
                      "AND sh.MassPeakID=mp.MassPeakID AND sh.ScanEventID=se.ScanEventID\n",
                      "AND mp.FileID=fi.FileID\n",
                      #AND p.SpectrumID = ss.SpectrumID\n",
                 "GROUP BY p.PeptideID;")
                 
cat(paste("Querying database [MSF file], ", basename(msfFile), " for PSM assigned peptides...\n",sep="",collapse=""))
rs_mtz <- dbSendQuery(con, sql_mtz)
mtzTab <- fetch(rs_mtz, n = -1)
dbClearResult(rs_mtz)
dbDisconnect(con)

cat("writing DB table...\n")
write.table(mtzTab, file = outputTablePath, sep="\t", quote=FALSE, row.names = FALSE)

# report execution:
if(file.exists(outputTablePath)){
  cat(paste("output table; ", basename(outputTablePath), " printed!",sep="",collapse=""))
} else {
  cat("...Hmmn, table not outputted..")
}
