args <- commandArgs(TRUE)
msfFile <- args[[1]]
outputTablePath <- args[[2]]

cat("Loading R libraries...\n")
require(RSQLite)
#require(sqldf)
driver = dbDriver("SQLite")
con <- dbConnect(driver, dbname = msfFile)
#confidence <- switch(minConf, High = 3, Medium = 2, Low = 1, 3)
confidence <- 1  # default to capture all identifications

sql_mtz <- paste(# ----- Place the SQL Query here ----- #
                  "SELECT p.Sequence AS PeptideSequence,\n",
                         "pprot.PeptideID,\n",
                         "pprot.ProteinID,\n",
                         "prot.Sequence,\n",
                         "prot.IsMasterProtein,\n",
                         "protAnnot.Description,\n",
                         #"protPrGrp.ProteinGroupID,\n",
                         "pscores.ProteinScore\n",
                  "FROM PeptidesProteins pprot\n",
                  "INNER JOIN Peptides p ON pprot.PeptideID=p.PeptideID\n",
                  "INNER JOIN Proteins prot ON pprot.ProteinID=prot.ProteinID\n",
                  "INNER JOIN ProteinAnnotations protAnnot ON pprot.ProteinID = protAnnot.ProteinID\n",
                  #"INNER JOIN ProteinsProteinGroups protPrGrp ON pprot.ProteinID = protPrGrp.ProteinID\n",
                  "INNER JOIN ProteinScores pscores ON pprot.ProteinID = pscores.ProteinID;"
                 )

cat(paste("Querying database [MSF file], ", basename(msfFile), " for PSM assigned proteins...\n",sep="",collapse=""))
rs_mtz <- dbSendQuery(con, sql_mtz)
mtzTab <- fetch(rs_mtz, n = -1)
dbClearResult(rs_mtz)
dbDisconnect(con)

cat("writing DB table...\n")
write.table(mtzTab, file = outputTablePath, sep="\t", quote=FALSE, row.names = FALSE)

# report execution:
if(file.exists(outputTablePath)){
  cat(paste("output table; ", basename(outputTablePath), " printed!",sep="",collapse=""))
} else {
  cat("...Hmmn, table not outputted..")
}
